@@ -21,6 +21,7 @@ import org.gcube.portlets.user.td.gwtservice.shared.geospatial.GeospatialCreateC
 import org.gcube.portlets.user.td.gwtservice.shared.geospatial.GeospatialDownscaleCSquareSession;
 import org.gcube.portlets.user.td.gwtservice.shared.history.OpHistory;
 import org.gcube.portlets.user.td.gwtservice.shared.history.RollBackSession;
+import org.gcube.portlets.user.td.gwtservice.shared.i18n.InfoLocale;
 import org.gcube.portlets.user.td.gwtservice.shared.json.JSONExportSession;
 import org.gcube.portlets.user.td.gwtservice.shared.licenses.LicenceData;
 import org.gcube.portlets.user.td.gwtservice.shared.map.MapCreationSession;
@@ -30,6 +31,7 @@ import org.gcube.portlets.user.td.gwtservice.shared.monitor.OperationMonitor;
 import org.gcube.portlets.user.td.gwtservice.shared.monitor.OperationMonitorSession;
 import org.gcube.portlets.user.td.gwtservice.shared.sdmx.SDMXExportSession;
 import org.gcube.portlets.user.td.gwtservice.shared.sdmx.SDMXImportSession;
+import org.gcube.portlets.user.td.gwtservice.shared.share.ShareRule;
 import org.gcube.portlets.user.td.gwtservice.shared.share.ShareTabResource;
 import org.gcube.portlets.user.td.gwtservice.shared.share.ShareTemplate;
 import org.gcube.portlets.user.td.gwtservice.shared.source.SDMXRegistrySource;
@@ -113,6 +115,15 @@ public interface TDGWTService extends RemoteService {
 	 */
 	public UserInfo hello() throws TDGWTServiceException;
 
+	
+	/**
+	 * Set locale on server
+	 * 
+	 * @param infoLocale
+	 * @throws TDGWTServiceException
+	 */
+	public void setLocale(InfoLocale infoLocale) throws TDGWTServiceException;
+	
 	/**
 	 * Retrieve pending Tasks and set them as background tasks
 	 * 
@@ -419,6 +430,16 @@ public interface TDGWTService extends RemoteService {
 	public ArrayList<ColumnData> getValidationColumns(String columnLocalId,
 			TRId trId) throws TDGWTServiceException;
 
+	/**
+	 * Remove Validations from tabular resource
+	 * 
+	 * @param trId
+	 * @return
+	 * @throws TDGWTServiceException
+	 */
+	public String startValidationsDelete(TRId trId)
+			throws TDGWTServiceException;
+
 	// RollBack
 	/**
 	 * Call rollback on tabular resource
@@ -459,6 +480,15 @@ public interface TDGWTService extends RemoteService {
 	public void setShareTemplate(ShareTemplate shareTemplate)
 			throws TDGWTServiceException;
 
+	/**
+	 * Share Rule
+	 * 
+	 * @param shareRule
+	 * @return
+	 * @throws TDGWTServiceException
+	 */
+	public void setShareRule(ShareRule shareRule) throws TDGWTServiceException;
+
 	// Open
 
 	/**
@@ -556,11 +586,11 @@ public interface TDGWTService extends RemoteService {
 	 */
 	public ArrayList<ColumnData> getColumnWithViewColumnIncluded(TRId trId)
 			throws TDGWTServiceException;
-	
+
 	/**
-	 * Retrieves the list of columns in the table provided by trId 
-	 * only view columns in relationship are included.
-	 * TimeDimensionColumn and DimensionColumn are not included. 
+	 * Retrieves the list of columns in the table provided by trId only view
+	 * columns in relationship are included. TimeDimensionColumn and
+	 * DimensionColumn are not included.
 	 * 
 	 * 
 	 * @param trId
@@ -569,7 +599,7 @@ public interface TDGWTService extends RemoteService {
 	 */
 	public ArrayList<ColumnData> getColumnWithOnlyViewColumnInRel(TRId trId)
 			throws TDGWTServiceException;
-	
+
 	/**
 	 * Retrieves the list of columns in the table provided by trId for
 	 * statistical
@@ -720,6 +750,17 @@ public interface TDGWTService extends RemoteService {
 			throws TDGWTServiceException;
 
 	// Export CSV
+	/**
+	 * Available charset for export
+	 * 
+	 * @return
+	 * @throws TDGWTServiceException
+	 */
+	public AvailableCharsetList getAvailableCharsetForExport()
+			throws TDGWTServiceException;
+
+	
+	
 	/**
 	 * Start CSV Export and invokes the client library
 	 * 
